"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from datetime import datetime
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional, Union
from typing_extensions import NotRequired, TypeAliasType, TypedDict


EventCreateExternalCustomerMetadataTypedDict = TypeAliasType(
    "EventCreateExternalCustomerMetadataTypedDict", Union[str, int, bool]
)


EventCreateExternalCustomerMetadata = TypeAliasType(
    "EventCreateExternalCustomerMetadata", Union[str, int, bool]
)


class EventCreateExternalCustomerTypedDict(TypedDict):
    name: str
    r"""The name of the event."""
    external_customer_id: str
    r"""ID of the customer in your system associated with the event."""
    metadata: NotRequired[Dict[str, EventCreateExternalCustomerMetadataTypedDict]]
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be either:

    * A string with a maximum length of **500 characters**
    * An integer
    * A boolean

    You can store up to **50 key-value pairs**.
    """
    timestamp: NotRequired[datetime]
    r"""The timestamp of the event."""
    organization_id: NotRequired[Nullable[str]]
    r"""The ID of the organization owning the event. **Required unless you use an organization token.**"""


class EventCreateExternalCustomer(BaseModel):
    name: str
    r"""The name of the event."""

    external_customer_id: str
    r"""ID of the customer in your system associated with the event."""

    metadata: Optional[Dict[str, EventCreateExternalCustomerMetadata]] = None
    r"""Key-value object allowing you to store additional information.

    The key must be a string with a maximum length of **40 characters**.
    The value must be either:

    * A string with a maximum length of **500 characters**
    * An integer
    * A boolean

    You can store up to **50 key-value pairs**.
    """

    timestamp: Optional[datetime] = None
    r"""The timestamp of the event."""

    organization_id: OptionalNullable[str] = UNSET
    r"""The ID of the organization owning the event. **Required unless you use an organization token.**"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["metadata", "timestamp", "organization_id"]
        nullable_fields = ["organization_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .customfieldupdatecheckbox import (
    CustomFieldUpdateCheckbox,
    CustomFieldUpdateCheckboxTypedDict,
)
from .customfieldupdatedate import CustomFieldUpdateDate, CustomFieldUpdateDateTypedDict
from .customfieldupdatenumber import (
    CustomFieldUpdateNumber,
    CustomFieldUpdateNumberTypedDict,
)
from .customfieldupdateselect import (
    CustomFieldUpdateSelect,
    CustomFieldUpdateSelectTypedDict,
)
from .customfieldupdatetext import CustomFieldUpdateText, CustomFieldUpdateTextTypedDict
from polar_sdk.utils import get_discriminator
from pydantic import Discriminator, Tag
from typing import Union
from typing_extensions import Annotated, TypeAliasType


CustomFieldUpdateTypedDict = TypeAliasType(
    "CustomFieldUpdateTypedDict",
    Union[
        CustomFieldUpdateTextTypedDict,
        CustomFieldUpdateNumberTypedDict,
        CustomFieldUpdateDateTypedDict,
        CustomFieldUpdateCheckboxTypedDict,
        CustomFieldUpdateSelectTypedDict,
    ],
)


CustomFieldUpdate = Annotated[
    Union[
        Annotated[CustomFieldUpdateCheckbox, Tag("checkbox")],
        Annotated[CustomFieldUpdateDate, Tag("date")],
        Annotated[CustomFieldUpdateNumber, Tag("number")],
        Annotated[CustomFieldUpdateSelect, Tag("select")],
        Annotated[CustomFieldUpdateText, Tag("text")],
    ],
    Discriminator(lambda m: get_discriminator(m, "type", "type")),
]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .organizationdetails import OrganizationDetails, OrganizationDetailsTypedDict
from .organizationfeaturesettings import (
    OrganizationFeatureSettings,
    OrganizationFeatureSettingsTypedDict,
)
from .organizationsociallink import (
    OrganizationSocialLink,
    OrganizationSocialLinkTypedDict,
)
from .organizationsubscriptionsettings import (
    OrganizationSubscriptionSettings,
    OrganizationSubscriptionSettingsTypedDict,
)
from polar_sdk.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class OrganizationCreateTypedDict(TypedDict):
    name: str
    slug: str
    avatar_url: NotRequired[Nullable[str]]
    email: NotRequired[Nullable[str]]
    r"""Public support email."""
    website: NotRequired[Nullable[str]]
    r"""Official website of the organization."""
    socials: NotRequired[Nullable[List[OrganizationSocialLinkTypedDict]]]
    r"""Link to social profiles."""
    details: NotRequired[Nullable[OrganizationDetailsTypedDict]]
    r"""Additional, private, business details Polar needs about active organizations for compliance (KYC)."""
    feature_settings: NotRequired[Nullable[OrganizationFeatureSettingsTypedDict]]
    subscription_settings: NotRequired[
        Nullable[OrganizationSubscriptionSettingsTypedDict]
    ]


class OrganizationCreate(BaseModel):
    name: str

    slug: str

    avatar_url: OptionalNullable[str] = UNSET

    email: OptionalNullable[str] = UNSET
    r"""Public support email."""

    website: OptionalNullable[str] = UNSET
    r"""Official website of the organization."""

    socials: OptionalNullable[List[OrganizationSocialLink]] = UNSET
    r"""Link to social profiles."""

    details: OptionalNullable[OrganizationDetails] = UNSET
    r"""Additional, private, business details Polar needs about active organizations for compliance (KYC)."""

    feature_settings: OptionalNullable[OrganizationFeatureSettings] = UNSET

    subscription_settings: OptionalNullable[OrganizationSubscriptionSettings] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "avatar_url",
            "email",
            "website",
            "socials",
            "details",
            "feature_settings",
            "subscription_settings",
        ]
        nullable_fields = [
            "avatar_url",
            "email",
            "website",
            "socials",
            "details",
            "feature_settings",
            "subscription_settings",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in self.model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
